﻿#region Copyright Syncfusion Inc. 2001 - 2012
// Copyright Syncfusion Inc. 2001 - 2012. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Syncfusion.Core;
using Syncfusion.Mvc.Shared;
using Syncfusion.Mvc.Diagram;
using System.Web.UI.WebControls;
using Sample1.Models;
using System.IO;


namespace Sample1.Controllers
{
    public class HomeController : Controller
    {
        static MemoryStream saveStream = new MemoryStream();
        DiagramPropertiesModel dp = new DiagramPropertiesModel();

        public ActionResult Index(string ActionHandler)
        {

            Node node1 = AddNode("Movie", "Movie", 100.00,200.00, Shapes.Rectangle, 100.00, 50.00, "orange");
            Node node2 = AddNode("Show", "Show", 300.00, 200.00, Shapes.Rectangle, 100.00, 50.00, "orange");
            Node node3 = AddNode("Director", "Director", 25.00, 75.00, Shapes.Ellipse, 100.00, 50.00, "blue");
            Node node4 = AddNode("Title", "Title", 150.00, 75.00, Shapes.Ellipse, 100.00, 50.00, "blue");
            Node node5 = AddNode("Date", "Date", 250.00, 75.00, Shapes.Ellipse, 100.00, 50.00, "yellow");
            Node node6 = AddNode("Time", "Time", 450.00, 75.00, Shapes.Ellipse, 100.00, 50.00, "yellow");
            LineConnector line1 = AddConnector("line1", node1, node2, "");
            LineConnector line2 = AddConnector("line2", node3, node1, "");
            LineConnector line3 = AddConnector("line3", node4, node1, "");
            LineConnector line4 = AddConnector("line4", node5, node2, "");
            LineConnector line6 = AddConnector("line5", node6, node2, "");
            dp.Nodes = new NodesCollection
            {
                node1,node2,node3,node4,node5,node6
            };

            dp.Connectors = new LinesCollection
            {
                line1,line2,line3,line4,line6
            };
            if (TempData["SaveAction"] != null && TempData["SaveAction"].ToString() == "Stream")
            {
                byte[] ms = saveStream.ToArray();
                this.SaveDiagramContent(ms);
                dp.Load(saveStream);
                TempData["SaveAction"] = null;
            }
            else 
                {
                saveStream = new MemoryStream();
            }
          

                     
          
            dp.Width = Unit.Pixel(750);
            dp.Height = Unit.Pixel(550);

            dp.EnableZOrder = true;
            dp.AllowMultipleSelect = true;
            dp.DiagramMode = DiagramMode.SVG;
            dp.SaveStreamMapper = "SaveDiagramAsStream";
            
            if (ActionHandler == "LoadStream")
            {
                saveStream = new MemoryStream();
                saveStream = this.LoadDiagramContent();
                dp.Load(saveStream);
            }

            ViewData["FlatDiagram"] = dp;
            return View();

        }
        

        public ActionResult About()
        {
            return View();
        }
        public Node AddNode(string name, string label, double offsetX, double offsetY, Shapes shape, double width, double height, string bgColor)
        {
            Node node = new Node()
            {
                Name = name,
                Label = label,
                LabelHorizontalAlignment = Horizontal.Center,
                LabelVerticalAlignment = Vertical.Middle,
                OffsetX = offsetX,
                OffsetY = offsetY,
                Shape = shape,
                Height = height,
                Width = width,
                BackgroundColor = bgColor != null && bgColor != "" ? bgColor : "#fff",                     
                LabelFontColor = "black",
                LabelFontSize = 12,
                LabelFontFamily = "Times New Roman"
            };
            return node;
        }
        public LineConnector AddConnector(string name, Node headNode, Node tailNode, string label)
        {
            LineConnector lineConnector = new LineConnector()
            {
                Name = name,
                HeadNode = headNode,
                TailNode = tailNode,
                HeadDecoratorShape = DecoratorShape.None,
                TailDecoratorShape = DecoratorShape.None,

                ConnectorType = ConnectorType.Orthogonal,
                LineColor = "#7a7772",
                LineWidth = 2,
                Label = label,
                LineDistributingEnabled = true,
            };
            return lineConnector;
            
        }
        public ActionResult SaveDiagramAsStream(DiagramPropertiesModel diagramModel)
        {
            saveStream = new MemoryStream();
            TempData["SaveAction"] = "Stream";
            return diagramModel.Save(saveStream);
        }

        public Northwind SqlCE
        {
            get
            {
                AppDomain.CurrentDomain.SetData("SQLServerCompactEditionUnderWebHosting", true);
                string connectionString = @"Data Source=|DataDirectory|\Northwind.sdf";
                return new Northwind(connectionString);
            }
        }
        private MemoryStream LoadDiagramContent()
        {
            MemoryStream outStream = new MemoryStream();
            byte[] ms = null;
            Northwind context = SqlCE;
            Serialize main = context.Serialize.Single(s => s.UserName == "Syncfusion");
            if (main != null)
            {
                ms = main.DiagramContent.ToArray();
                outStream.Write(ms, 0, ms.Length);
            }
            return outStream;
        }
        private void SaveDiagramContent(byte[] ms)
        {
            Northwind context = SqlCE;
            List<Serialize> lstUsers = context.Serialize.Where(d => d.UserName == "Syncfusion").ToList();
            if (lstUsers.Count > 0)
            {
                Serialize main = context.Serialize.Single(s => s.UserName == "Syncfusion");
                main.DiagramContent = ms;
            }
            else
            {
                Serialize appoint = new Serialize()
                {
                    Id = 1,
                    UserName = "Syncfusion",
                    Password = "****",
                    DiagramContent = ms
                };
                context.Serialize.InsertOnSubmit(appoint);
            }
            context.SubmitChanges();
        }

        
       
    }

}



